@@ -1,5 +1,5 @@
 /*
- * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @copyright Copyright (c) Open-Xchange GmbH, Germany <info@open-xchange.com>
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -291,18 +291,27 @@ public class WebSocketPushNotificationTransport implements PushNotificationTrans
 
         ComposedConfigProperty<Boolean> property;
         property = null == topic || null == client ? null : view.property(basePropertyName + "." + client + "." + topic, boolean.class);
-        if (null != property && property.isDefined()) {
-            return property.get().booleanValue();
+        if (null != property) {
+            Boolean value = property.get();
+            if (value != null) {
+                return value.booleanValue();
+            }
         }
 
         property = null == client ? null : view.property(basePropertyName + "." + client, boolean.class);
-        if (null != property && property.isDefined()) {
-            return property.get().booleanValue();
+        if (null != property) {
+            Boolean value = property.get();
+            if (value != null) {
+                return value.booleanValue();
+            }
         }
 
         property = view.property(basePropertyName, boolean.class);
-        if (null != property && property.isDefined()) {
-            return property.get().booleanValue();
+        if (null != property) {
+            Boolean value = property.get();
+            if (value != null) {
+                return value.booleanValue();
+            }
         }
 
         // Default is "true"
